gnunet-svn
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[GNUnet-SVN] r29888 - in gnunet/src: include transport util


From: gnunet
Subject: [GNUnet-SVN] r29888 - in gnunet/src: include transport util
Date: Sun, 6 Oct 2013 11:35:15 +0200

Author: grothoff
Date: 2013-10-06 11:35:14 +0200 (Sun, 06 Oct 2013)
New Revision: 29888

Modified:
   gnunet/src/include/gnunet_bio_lib.h
   gnunet/src/include/gnunet_disk_lib.h
   gnunet/src/transport/plugin_transport_http.c
   gnunet/src/transport/plugin_transport_http_server.c
   gnunet/src/util/bio.c
   gnunet/src/util/disk.c
Log:
-doxygen, coding conventions

Modified: gnunet/src/include/gnunet_bio_lib.h
===================================================================
--- gnunet/src/include/gnunet_bio_lib.h 2013-10-06 09:28:24 UTC (rev 29887)
+++ gnunet/src/include/gnunet_bio_lib.h 2013-10-06 09:35:14 UTC (rev 29888)
@@ -104,12 +104,12 @@
  * @param what describes what is being read (for error message creation)
  * @param result the buffer to store a pointer to the (allocated) string to
  *        (note that *result could be set to NULL as well)
  * @param maxLen maximum allowed length for the string
  * @return #GNUNET_OK on success, #GNUNET_SYSERR on failure
  */
 int
 GNUNET_BIO_read_string (struct GNUNET_BIO_ReadHandle *h, const char *what,
-                        char **result, size_t maxLen);
+                        char **result, size_t max_length);
 
 
 /**

Modified: gnunet/src/include/gnunet_disk_lib.h
===================================================================
--- gnunet/src/include/gnunet_disk_lib.h        2013-10-06 09:28:24 UTC (rev 
29887)
+++ gnunet/src/include/gnunet_disk_lib.h        2013-10-06 09:35:14 UTC (rev 
29888)
@@ -387,7 +387,7 @@
  * @param fn file name to be opened
  * @param flags opening flags, a combination of GNUNET_DISK_OPEN_xxx bit flags
  * @param perm permissions for the newly created file, use
- *             GNUNET_DISK_PERM_NONE if a file could not be created by this
+ *             #GNUNET_DISK_PERM_NONE if a file could not be created by this
  *             call (because of flags)
  * @return IO handle on success, NULL on error
  */
@@ -401,7 +401,7 @@
  *
  * @param fh open file handle
  * @param size where to write size of the file
- * @return GNUNET_OK on success, GNUNET_SYSERR on error
+ * @return #GNUNET_OK on success, #GNUNET_SYSERR on error
  */
 int
 GNUNET_DISK_file_handle_size (struct GNUNET_DISK_FileHandle *fh,
@@ -411,8 +411,8 @@
 /**
  * Creates an interprocess channel
  *
- * @param blocking_read creates an asynchronous pipe for reading if set to 
GNUNET_NO
- * @param blocking_write creates an asynchronous pipe for writing if set to 
GNUNET_NO
+ * @param blocking_read creates an asynchronous pipe for reading if set to 
#GNUNET_NO
+ * @param blocking_write creates an asynchronous pipe for writing if set to 
#GNUNET_NO
  * @param inherit_read 1 to make read handle inheritable, 0 otherwise (NT only)
  * @param inherit_write 1 to make write handle inheritable, 0 otherwise (NT 
only)
  * @return handle to the new pipe, NULL on error
@@ -425,8 +425,8 @@
  * Creates a pipe object from a couple of file descriptors.
  * Useful for wrapping existing pipe FDs.
  *
- * @param blocking_read creates an asynchronous pipe for reading if set to 
GNUNET_NO
- * @param blocking_write creates an asynchronous pipe for writing if set to 
GNUNET_NO
+ * @param blocking_read creates an asynchronous pipe for reading if set to 
#GNUNET_NO
+ * @param blocking_write creates an asynchronous pipe for writing if set to 
#GNUNET_NO
  * @param fd an array of two fd values. One of them may be -1 for read-only or 
write-only pipes
  *
  * @return handle to the new pipe, NULL on error
@@ -438,7 +438,7 @@
 /**
  * Closes an interprocess channel
  * @param p pipe
- * @return GNUNET_OK on success, GNUNET_SYSERR otherwise
+ * @return #GNUNET_OK on success, #GNUNET_SYSERR otherwise
  */
 int
 GNUNET_DISK_pipe_close (struct GNUNET_DISK_PipeHandle *p);
@@ -449,12 +449,13 @@
  *
  * @param p pipe to close end of
  * @param end which end of the pipe to close
- * @return GNUNET_OK on success, GNUNET_SYSERR otherwise
+ * @return #GNUNET_OK on success, #GNUNET_SYSERR otherwise
  */
 int
 GNUNET_DISK_pipe_close_end (struct GNUNET_DISK_PipeHandle *p,
                             enum GNUNET_DISK_PipeEnd end);
 
+
 /**
  * Detaches one of the ends from the pipe.
  * Detached end is a fully-functional FileHandle, it will
@@ -505,6 +506,7 @@
 GNUNET_DISK_get_handle_from_w32_handle (HANDLE osfh);
 #endif
 
+
 /**
  * Get a handle from a native integer FD.
  *
@@ -514,6 +516,7 @@
 struct GNUNET_DISK_FileHandle *
 GNUNET_DISK_get_handle_from_int_fd (int fno);
 
+
 /**
  * Get a handle from a native FD.
  *
@@ -529,7 +532,7 @@
  * @param h handle to an open file
  * @param result the buffer to write the result to
  * @param len the maximum number of bytes to read
- * @return the number of bytes read on success, GNUNET_SYSERR on failure
+ * @return the number of bytes read on success, #GNUNET_SYSERR on failure
  */
 ssize_t
 GNUNET_DISK_file_read (const struct GNUNET_DISK_FileHandle *h, void *result,
@@ -544,11 +547,12 @@
  * @param h handle to an open file
  * @param result the buffer to write the result to
  * @param len the maximum number of bytes to read
- * @return the number of bytes read on success, GNUNET_SYSERR on failure
+ * @return the number of bytes read on success, #GNUNET_SYSERR on failure
  */
 ssize_t
 GNUNET_DISK_file_read_non_blocking (const struct GNUNET_DISK_FileHandle * h,
-                                   void *result, size_t len);
+                                   void *result,
+                                    size_t len);
 
 
 /**
@@ -557,10 +561,12 @@
  * @param fn file name
  * @param result the buffer to write the result to
  * @param len the maximum number of bytes to read
- * @return number of bytes read, GNUNET_SYSERR on failure
+ * @return number of bytes read, #GNUNET_SYSERR on failure
  */
 ssize_t
-GNUNET_DISK_fn_read (const char *fn, void *result, size_t len);
+GNUNET_DISK_fn_read (const char *fn,
+                     void *result, 
+                     size_t len);
 
 
 /**
@@ -569,7 +575,7 @@
  * @param h handle to open file
  * @param buffer the data to write
  * @param n number of bytes to write
- * @return number of bytes written on success, GNUNET_SYSERR on error
+ * @return number of bytes written on success, #GNUNET_SYSERR on error
  */
 ssize_t
 GNUNET_DISK_file_write (const struct GNUNET_DISK_FileHandle *h,
@@ -581,7 +587,7 @@
  * @param h handle to open file
  * @param buffer the data to write
  * @param n number of bytes to write
- * @return number of bytes written on success, GNUNET_SYSERR on error
+ * @return number of bytes written on success, #GNUNET_SYSERR on error
  */
 ssize_t
 GNUNET_DISK_file_write_blocking (const struct GNUNET_DISK_FileHandle * h,
@@ -597,7 +603,7 @@
  * @param buffer the data to write
  * @param n number of bytes to write
  * @param mode file permissions
- * @return number of bytes written on success, GNUNET_SYSERR on error
+ * @return number of bytes written on success, #GNUNET_SYSERR on error
  */
 ssize_t
 GNUNET_DISK_fn_write (const char *fn, const void *buffer, size_t n,
@@ -609,7 +615,7 @@
  *
  * @param src file to copy
  * @param dst destination file name
- * @return GNUNET_OK on success, GNUNET_SYSERR on error
+ * @return #GNUNET_OK on success, #GNUNET_SYSERR on error
  */
 int
 GNUNET_DISK_file_copy (const char *src, const char *dst);
@@ -618,13 +624,13 @@
 /**
  * Scan a directory for files.
  *
  * @param dirName the name of the directory
  * @param callback the method to call for each file
- * @param callback_cls closure for callback
+ * @param callback_cls closure for @a callback
  * @return the number of files found, -1 on error
  */
 int
-GNUNET_DISK_directory_scan (const char *dirName,
+GNUNET_DISK_directory_scan (const char *dir_name,
                             GNUNET_FileNameCallback callback,
                             void *callback_cls);
 
@@ -639,16 +645,14 @@
  * Function called to iterate over a directory.
  *
  * @param cls closure
- * @param di argument to pass to "GNUNET_DISK_directory_iterator_next" to
+ * @param di argument to pass to #GNUNET_DISK_directory_iterator_next to
  *           get called on the next entry (or finish cleanly);
  *           NULL on error (will be the last call in that case)
  * @param filename complete filename (absolute path)
  * @param dirname directory name (absolute path)
  */
 typedef void (*GNUNET_DISK_DirectoryIteratorCallback) (void *cls,
-                                                       struct
-                                                       
GNUNET_DISK_DirectoryIterator
-                                                       * di,
+                                                       struct 
GNUNET_DISK_DirectoryIterator *di,
                                                        const char *filename,
                                                        const char *dirname);
 
@@ -659,10 +663,10 @@
  * filename in the directory (if there is one).
  *
  * @param iter opaque handle for the iterator
- * @param can set to GNUNET_YES to terminate the iteration early
- * @return GNUNET_YES if iteration will continue,
- *         GNUNET_NO if this was the last entry (and iteration is complete),
- *         GNUNET_SYSERR if "can" was YES
+ * @param can set to #GNUNET_YES to terminate the iteration early
+ * @return #GNUNET_YES if iteration will continue,
+ *         #GNUNET_NO if this was the last entry (and iteration is complete),
+ *         #GNUNET_SYSERR if @a can was #GNUNET_YES
  */
 int
 GNUNET_DISK_directory_iterator_next (struct GNUNET_DISK_DirectoryIterator 
*iter,
@@ -676,15 +680,15 @@
  * may provide a simpler API.
  *
  * @param prio priority to use
  * @param dirName the name of the directory
  * @param callback the method to call for each file
- * @param callback_cls closure for callback
- * @return GNUNET_YES if directory is not empty and 'callback'
- *         will be called later, GNUNET_NO otherwise, GNUNET_SYSERR on error.
+ * @param callback_cls closure for @a callback
+ * @return #GNUNET_YES if directory is not empty and @a callback
+ *         will be called later, #GNUNET_NO otherwise, #GNUNET_SYSERR on error.
  */
 int
 GNUNET_DISK_directory_iterator_start (enum GNUNET_SCHEDULER_Priority prio,
-                                      const char *dirName,
+                                      const char *dir_name,
                                       GNUNET_DISK_DirectoryIteratorCallback
                                       callback, void *callback_cls);
 
@@ -694,24 +698,24 @@
  * a file.
  *
  * @param filename name of a file in the directory
- * @returns GNUNET_OK on success, GNUNET_SYSERR on failure,
- *          GNUNET_NO if directory exists but is not writeable
+ * @returns #GNUNET_OK on success, #GNUNET_SYSERR on failure,
+ *          #GNUNET_NO if directory exists but is not writeable
  */
 int
 GNUNET_DISK_directory_create_for_file (const char *filename);
 
 
 /**
- * Test if "fil" is a directory and listable. Optionally, also check if the
+ * Test if @a fil is a directory and listable. Optionally, also check if the
  * directory is readable.  Will not print an error message if the directory 
does
- * not exist.  Will log errors if GNUNET_SYSERR is returned (i.e., a file 
exists
+ * not exist.  Will log errors if #GNUNET_SYSERR is returned (i.e., a file 
exists
  * with the same name).
  *
  * @param fil filename to test
- * @param is_readable GNUNET_YES to additionally check if "fil" is readable;
- *          GNUNET_NO to disable this check
- * @return GNUNET_YES if yes, GNUNET_NO if not; GNUNET_SYSERR if it
- *           does not exist or stat'ed
+ * @param is_readable #GNUNET_YES to additionally check if @a fil is readable;
+ *          #GNUNET_NO to disable this check
+ * @return #GNUNET_YES if yes, #GNUNET_NO if not; #GNUNET_SYSERR if it
+ *           does not exist or `stat`ed
  */
 int
 GNUNET_DISK_directory_test (const char *fil, int is_readable);
@@ -742,27 +746,28 @@
  * Lock a part of a file.
  *
  * @param fh file handle
  * @param lockStart absolute position from where to lock
  * @param lockEnd absolute position until where to lock
  * @param excl #GNUNET_YES for an exclusive lock
  * @return #GNUNET_OK on success, #GNUNET_SYSERR on error
  */
 int
-GNUNET_DISK_file_lock (struct GNUNET_DISK_FileHandle *fh, OFF_T lockStart,
-                       OFF_T lockEnd, int excl);
+GNUNET_DISK_file_lock (struct GNUNET_DISK_FileHandle *fh, 
+                       OFF_T lock_start,
+                       OFF_T lock_end, int excl);
 
 
 /**
  * Unlock a part of a file.
  *
  * @param fh file handle
  * @param unlockStart absolute position from where to unlock
  * @param unlockEnd absolute position until where to unlock
  * @return #GNUNET_OK on success, #GNUNET_SYSERR on error
  */
 int
-GNUNET_DISK_file_unlock (struct GNUNET_DISK_FileHandle *fh, OFF_T unlockStart,
-                         OFF_T unlockEnd);
+GNUNET_DISK_file_unlock (struct GNUNET_DISK_FileHandle *fh, OFF_T unlock_start,
+                         OFF_T unlock_end);
 
 
 /**
@@ -791,7 +796,7 @@
  * DIR_SEPARATOR_STR as the last argument before NULL).
  *
  * @param cfg configuration to use
  * @param serviceName name of the service asking
  * @param ... is NULL-terminated list of
  *                path components to append to the
  *                private directory name.
@@ -799,7 +804,7 @@
  */
 char *
 GNUNET_DISK_get_home_filename (const struct GNUNET_CONFIGURATION_Handle *cfg,
-                               const char *serviceName, ...);
+                               const char *service_name, ...);
 
 
 /**

Modified: gnunet/src/transport/plugin_transport_http.c
===================================================================
--- gnunet/src/transport/plugin_transport_http.c        2013-10-06 09:28:24 UTC 
(rev 29887)
+++ gnunet/src/transport/plugin_transport_http.c        2013-10-06 09:35:14 UTC 
(rev 29888)
@@ -829,7 +829,7 @@
 
 
 int
-http_get_addresses (struct Plugin *plugin, const char *serviceName,
+http_get_addresses (struct Plugin *plugin, const char *service_name,
                     const struct GNUNET_CONFIGURATION_Handle *cfg,
                     struct sockaddr ***addrs, socklen_t ** addr_lens)
 {
@@ -852,10 +852,10 @@
   disablev6 = !plugin->ipv6;
 
   port = 0;
-  if (GNUNET_CONFIGURATION_have_value (cfg, serviceName, "PORT"))
+  if (GNUNET_CONFIGURATION_have_value (cfg, service_name, "PORT"))
   {
     GNUNET_break (GNUNET_OK ==
-                  GNUNET_CONFIGURATION_get_value_number (cfg, serviceName,
+                  GNUNET_CONFIGURATION_get_value_number (cfg, service_name,
                                                          "PORT", &port));
     if (port > 65535)
     {
@@ -873,10 +873,10 @@
   }
 
 
-  if (GNUNET_CONFIGURATION_have_value (cfg, serviceName, "BINDTO"))
+  if (GNUNET_CONFIGURATION_have_value (cfg, service_name, "BINDTO"))
   {
     GNUNET_break (GNUNET_OK ==
-                  GNUNET_CONFIGURATION_get_value_string (cfg, serviceName,
+                  GNUNET_CONFIGURATION_get_value_string (cfg, service_name,
                                                          "BINDTO", &hostname));
   }
   else
@@ -886,7 +886,7 @@
   {
     GNUNET_log_from (GNUNET_ERROR_TYPE_DEBUG, plugin->name,
                      "Resolving `%s' since that is where `%s' will bind to.\n",
-                     hostname, serviceName);
+                     hostname, service_name);
     memset (&hints, 0, sizeof (struct addrinfo));
     if (disablev6)
       hints.ai_family = AF_INET;

Modified: gnunet/src/transport/plugin_transport_http_server.c
===================================================================
--- gnunet/src/transport/plugin_transport_http_server.c 2013-10-06 09:28:24 UTC 
(rev 29887)
+++ gnunet/src/transport/plugin_transport_http_server.c 2013-10-06 09:35:14 UTC 
(rev 29888)
@@ -2341,7 +2341,7 @@
  * Get valid server addresses
  *
  * @param plugin the plugin handle
- * @param serviceName the servicename
+ * @param service_name the servicename
  * @param cfg configuration handle
  * @param addrs addresses
  * @param addr_lens address length
@@ -2349,7 +2349,7 @@
  */
 static int
 server_get_addresses (struct HTTP_Server_Plugin *plugin,
-                      const char *serviceName,
+                      const char *service_name,
                       const struct GNUNET_CONFIGURATION_Handle *cfg,
                       struct sockaddr ***addrs, socklen_t ** addr_lens)
 {
@@ -2372,10 +2372,10 @@
   disablev6 = !plugin->use_ipv6;
 
   port = 0;
-  if (GNUNET_CONFIGURATION_have_value (cfg, serviceName, "PORT"))
+  if (GNUNET_CONFIGURATION_have_value (cfg, service_name, "PORT"))
   {
     GNUNET_break (GNUNET_OK ==
-                  GNUNET_CONFIGURATION_get_value_number (cfg, serviceName,
+                  GNUNET_CONFIGURATION_get_value_number (cfg, service_name,
                                                          "PORT", &port));
     if (port > 65535)
     {
@@ -2393,10 +2393,10 @@
   }
 
 
-  if (GNUNET_CONFIGURATION_have_value (cfg, serviceName, "BINDTO"))
+  if (GNUNET_CONFIGURATION_have_value (cfg, service_name, "BINDTO"))
   {
     GNUNET_break (GNUNET_OK ==
-                  GNUNET_CONFIGURATION_get_value_string (cfg, serviceName,
+                  GNUNET_CONFIGURATION_get_value_string (cfg, service_name,
                                                          "BINDTO", &hostname));
   }
   else
@@ -2406,7 +2406,7 @@
   {
     GNUNET_log_from (GNUNET_ERROR_TYPE_DEBUG, plugin->name,
                      "Resolving `%s' since that is where `%s' will bind to.\n",
-                     hostname, serviceName);
+                     hostname, service_name);
     memset (&hints, 0, sizeof (struct addrinfo));
     if (disablev6)
       hints.ai_family = AF_INET;
@@ -104,12 +104,12 @@
  * @param result the buffer to store a pointer to the (allocated) string to
  *        (note that *result could be set to NULL as well)
- * @param maxLen maximum allowed length for the string
+ * @param max_length maximum allowed length for the string
  * @return #GNUNET_OK on success, #GNUNET_SYSERR on failure
  */
@@ -618,13 +624,13 @@
  * Scan a directory for files.
  *
- * @param dirName the name of the directory
+ * @param dir_name the name of the directory
  * @param callback the method to call for each file
@@ -676,15 +680,15 @@
  *
  * @param prio priority to use
- * @param dirName the name of the directory
+ * @param dir_name the name of the directory
  * @param callback the method to call for each file
@@ -742,27 +746,28 @@
  *
  * @param fh file handle
- * @param lockStart absolute position from where to lock
- * @param lockEnd absolute position until where to lock
+ * @param lock_start absolute position from where to lock
+ * @param lock_end absolute position until where to lock
  * @param excl #GNUNET_YES for an exclusive lock
  * @return #GNUNET_OK on success, #GNUNET_SYSERR on error
@@ -742,27 +746,28 @@
  *
  * @param fh file handle
- * @param unlockStart absolute position from where to unlock
- * @param unlockEnd absolute position until where to unlock
+ * @param unlock_start absolute position from where to unlock
+ * @param unlock_end absolute position until where to unlock
  * @return #GNUNET_OK on success, #GNUNET_SYSERR on error
  */
@@ -791,7 +796,7 @@
  *
  * @param cfg configuration to use
- * @param serviceName name of the service asking
+ * @param service_name name of the service asking
  * @param ... is NULL-terminated list of
  *                path components to append to the

Modified: gnunet/src/util/bio.c
===================================================================
--- gnunet/src/util/bio.c       2013-10-06 09:28:24 UTC (rev 29887)
+++ gnunet/src/util/bio.c       2013-10-06 09:35:14 UTC (rev 29888)
@@ -219,12 +219,14 @@
  * @param what describes what is being read (for error message creation)
  * @param result the buffer to store a pointer to the (allocated) string to
  *        (note that *result could be set to NULL as well)
  * @param maxLen maximum allowed length for the string
  * @return #GNUNET_OK on success, #GNUNET_SYSERR on failure
  */
 int
-GNUNET_BIO_read_string (struct GNUNET_BIO_ReadHandle *h, const char *what,
-                        char **result, size_t maxLen)
+GNUNET_BIO_read_string (struct GNUNET_BIO_ReadHandle *h,
+                        const char *what,
+                        char **result, 
+                        size_t max_length)
 {
   char *buf;
   uint32_t big;
@@ -240,10 +242,10 @@
     *result = NULL;
     return GNUNET_OK;
   }
-  if (big > maxLen)
+  if (big > max_length)
   {
     GNUNET_asprintf (&h->emsg, _("String `%s' longer than allowed (%u > %u)"),
-                     what, big, maxLen);
+                     what, big, max_length);
     return GNUNET_SYSERR;
   }
   buf = GNUNET_malloc (big);
@@ -270,7 +272,8 @@
  * @return #GNUNET_OK on success, #GNUNET_SYSERR on failure
  */
 int
-GNUNET_BIO_read_meta_data (struct GNUNET_BIO_ReadHandle *h, const char *what,
+GNUNET_BIO_read_meta_data (struct GNUNET_BIO_ReadHandle *h, 
+                           const char *what,
                            struct GNUNET_CONTAINER_MetaData **result)
 {
   uint32_t size;
@@ -344,7 +347,8 @@
 int
 GNUNET_BIO_read_int64__ (struct GNUNET_BIO_ReadHandle *h, 
                          const char *file,
-                         int line, int64_t * i)
+                         int line, 
+                         int64_t *i)
 {
   int64_t big;
 
@@ -219,12 +219,14 @@
  * @param result the buffer to store a pointer to the (allocated) string to
  *        (note that *result could be set to NULL as well)
- * @param maxLen maximum allowed length for the string
+ * @param max_length maximum allowed length for the string
  * @return #GNUNET_OK on success, #GNUNET_SYSERR on failure
  */

Modified: gnunet/src/util/disk.c
===================================================================
--- gnunet/src/util/disk.c      2013-10-06 09:28:24 UTC (rev 29887)
+++ gnunet/src/util/disk.c      2013-10-06 09:35:14 UTC (rev 29888)
@@ -1107,7 +1107,7 @@
 /**
  * Scan a directory for files.
  *
  * @param dirName the name of the directory
  * @param callback the method to call for each file,
  *        can be NULL, in that case, we only count
  * @param callback_cls closure for callback
@@ -1115,7 +1115,7 @@
  *         ieration aborted by callback returning GNUNET_SYSERR
  */
 int
-GNUNET_DISK_directory_scan (const char *dirName,
+GNUNET_DISK_directory_scan (const char *dir_name,
                             GNUNET_FileNameCallback callback,
                             void *callback_cls)
 {
@@ -1129,8 +1129,8 @@
   unsigned int name_len;
   unsigned int n_size;
 
-  GNUNET_assert (dirName != NULL);
-  dname = GNUNET_STRINGS_filename_expand (dirName);
+  GNUNET_assert (dir_name != NULL);
+  dname = GNUNET_STRINGS_filename_expand (dir_name);
   if (dname == NULL)
     return GNUNET_SYSERR;
   while ((strlen (dname) > 0) && (dname[strlen (dname) - 1] == DIR_SEPARATOR))
@@ -1144,7 +1144,7 @@
   if (!S_ISDIR (istat.st_mode))
   {
     LOG (GNUNET_ERROR_TYPE_WARNING, _("Expected `%s' to be a directory!\n"),
-         dirName);
+         dir_name);
     GNUNET_free (dname);
     return GNUNET_SYSERR;
   }
@@ -1310,7 +1310,7 @@
  * may provide a simpler API.
  *
  * @param prio priority to use
  * @param dirName the name of the directory
  * @param callback the method to call for each file
  * @param callback_cls closure for callback
  * @return GNUNET_YES if directory is not empty and 'callback'
@@ -1318,7 +1318,7 @@
  */
 int
 GNUNET_DISK_directory_iterator_start (enum GNUNET_SCHEDULER_Priority prio,
-                                      const char *dirName,
+                                      const char *dir_name,
                                       GNUNET_DISK_DirectoryIteratorCallback
                                       callback, void *callback_cls)
 {
@@ -1327,14 +1327,14 @@
   di = GNUNET_malloc (sizeof (struct GNUNET_DISK_DirectoryIterator));
   di->callback = callback;
   di->callback_cls = callback_cls;
-  di->directory = OPENDIR (dirName);
+  di->directory = OPENDIR (dir_name);
   if (di->directory == NULL)
   {
     GNUNET_free (di);
     callback (callback_cls, NULL, NULL, NULL);
     return GNUNET_SYSERR;
   }
-  di->dirname = GNUNET_strdup (dirName);
+  di->dirname = GNUNET_strdup (dir_name);
   di->priority = prio;
   return GNUNET_DISK_directory_iterator_next (di, GNUNET_NO);
 }
@@ -1400,10 +1400,11 @@
  *
  * @param src file to copy
  * @param dst destination file name
- * @return GNUNET_OK on success, GNUNET_SYSERR on error
+ * @return #GNUNET_OK on success, #GNUNET_SYSERR on error
  */
 int
-GNUNET_DISK_file_copy (const char *src, const char *dst)
+GNUNET_DISK_file_copy (const char *src, 
+                       const char *dst)
 {
   char *buf;
   uint64_t pos;
@@ -1514,14 +1515,14 @@
 /**
  * Lock a part of a file
  * @param fh file handle
  * @param lockStart absolute position from where to lock
  * @param lockEnd absolute position until where to lock
  * @param excl GNUNET_YES for an exclusive lock
  * @return GNUNET_OK on success, GNUNET_SYSERR on error
  */
 int
-GNUNET_DISK_file_lock (struct GNUNET_DISK_FileHandle *fh, OFF_T lockStart,
-                       OFF_T lockEnd, int excl)
+GNUNET_DISK_file_lock (struct GNUNET_DISK_FileHandle *fh, OFF_T lock_start,
+                       OFF_T lock_end, int excl)
 {
   if (fh == NULL)
   {
@@ -1535,20 +1536,20 @@
   memset (&fl, 0, sizeof (struct flock));
   fl.l_type = excl ? F_WRLCK : F_RDLCK;
   fl.l_whence = SEEK_SET;
-  fl.l_start = lockStart;
-  fl.l_len = lockEnd;
+  fl.l_start = lock_start;
+  fl.l_len = lock_end;
 
   return fcntl (fh->fd, F_SETLK, &fl) != 0 ? GNUNET_SYSERR : GNUNET_OK;
 #else
   OVERLAPPED o;
-  OFF_T diff = lockEnd - lockStart;
+  OFF_T diff = lock_end - lock_start;
   DWORD diff_low, diff_high;
   diff_low = (DWORD) (diff & 0xFFFFFFFF);
   diff_high = (DWORD) ((diff >> (sizeof (DWORD) * 8)) & 0xFFFFFFFF);
 
   memset (&o, 0, sizeof (OVERLAPPED));
-  o.Offset = (DWORD) (lockStart & 0xFFFFFFFF);;
-  o.OffsetHigh = (DWORD) (((lockStart & ~0xFFFFFFFF) >> (sizeof (DWORD) * 8)) 
& 0xFFFFFFFF);
+  o.Offset = (DWORD) (lock_start & 0xFFFFFFFF);;
+  o.OffsetHigh = (DWORD) (((lock_start & ~0xFFFFFFFF) >> (sizeof (DWORD) * 8)) 
& 0xFFFFFFFF);
 
   if (!LockFileEx
       (fh->h, (excl ? LOCKFILE_EXCLUSIVE_LOCK : 0) | LOCKFILE_FAIL_IMMEDIATELY,
@@ -1566,13 +1567,13 @@
 /**
  * Unlock a part of a file
  * @param fh file handle
  * @param unlockStart absolute position from where to unlock
  * @param unlockEnd absolute position until where to unlock
  * @return GNUNET_OK on success, GNUNET_SYSERR on error
  */
 int
-GNUNET_DISK_file_unlock (struct GNUNET_DISK_FileHandle *fh, OFF_T unlockStart,
-                         OFF_T unlockEnd)
+GNUNET_DISK_file_unlock (struct GNUNET_DISK_FileHandle *fh, OFF_T unlock_start,
+                         OFF_T unlock_end)
 {
   if (fh == NULL)
   {
@@ -1586,20 +1587,20 @@
   memset (&fl, 0, sizeof (struct flock));
   fl.l_type = F_UNLCK;
   fl.l_whence = SEEK_SET;
-  fl.l_start = unlockStart;
-  fl.l_len = unlockEnd;
+  fl.l_start = unlock_start;
+  fl.l_len = unlock_end;
 
   return fcntl (fh->fd, F_SETLK, &fl) != 0 ? GNUNET_SYSERR : GNUNET_OK;
 #else
   OVERLAPPED o;
-  OFF_T diff = unlockEnd - unlockStart;
+  OFF_T diff = unlock_end - unlock_start;
   DWORD diff_low, diff_high;
   diff_low = (DWORD) (diff & 0xFFFFFFFF);
   diff_high = (DWORD) ((diff >> (sizeof (DWORD) * 8)) & 0xFFFFFFFF);
 
   memset (&o, 0, sizeof (OVERLAPPED));
-  o.Offset = (DWORD) (unlockStart & 0xFFFFFFFF);;
-  o.OffsetHigh = (DWORD) (((unlockStart & ~0xFFFFFFFF) >> (sizeof (DWORD) * 
8)) & 0xFFFFFFFF);
+  o.Offset = (DWORD) (unlock_start & 0xFFFFFFFF);;
+  o.OffsetHigh = (DWORD) (((unlock_start & ~0xFFFFFFFF) >> (sizeof (DWORD) * 
8)) & 0xFFFFFFFF);
 
   if (!UnlockFileEx (fh->h, 0, diff_low, diff_high, &o))
   {
@@ -1620,12 +1621,13 @@
  * @param fn file name to be opened
  * @param flags opening flags, a combination of GNUNET_DISK_OPEN_xxx bit flags
  * @param perm permissions for the newly created file, use
- *             GNUNET_DISK_PERM_USER_NONE if a file could not be created by 
this
+ *             #GNUNET_DISK_PERM_USER_NONE if a file could not be created by 
this
  *             call (because of flags)
  * @return IO handle on success, NULL on error
  */
 struct GNUNET_DISK_FileHandle *
-GNUNET_DISK_file_open (const char *fn, enum GNUNET_DISK_OpenFlags flags,
+GNUNET_DISK_file_open (const char *fn,
+                       enum GNUNET_DISK_OpenFlags flags,
                        enum GNUNET_DISK_AccessPermissions perm)
 {
   char *expfn;
@@ -1925,7 +1927,7 @@
  * DIR_SEPARATOR_STR as the last argument before NULL).
  *
  * @param cfg configuration to use (determines HOME)
  * @param serviceName name of the service
  * @param ... is NULL-terminated list of
  *                path components to append to the
  *                private directory name.
@@ -1933,7 +1935,7 @@
  */
 char *
 GNUNET_DISK_get_home_filename (const struct GNUNET_CONFIGURATION_Handle *cfg,
-                               const char *serviceName, ...)
+                               const char *service_name, ...)
 {
   const char *c;
   char *pfx;
@@ -1942,19 +1944,19 @@
   unsigned int needed;
 
   if (GNUNET_OK !=
-      GNUNET_CONFIGURATION_get_value_filename (cfg, serviceName, "HOME", &pfx))
+      GNUNET_CONFIGURATION_get_value_filename (cfg, service_name, "HOME", 
&pfx))
     return NULL;
   if (pfx == NULL)
   {
     LOG (GNUNET_ERROR_TYPE_WARNING,
          _("No `%s' specified for service `%s' in configuration.\n"), "HOME",
-         serviceName);
+         service_name);
     return NULL;
   }
   needed = strlen (pfx) + 2;
   if ((pfx[strlen (pfx) - 1] != '/') && (pfx[strlen (pfx) - 1] != '\\'))
     needed++;
-  va_start (ap, serviceName);
+  va_start (ap, service_name);
   while (1)
   {
     c = va_arg (ap, const char *);
@@ -1969,7 +1971,7 @@
   ret = GNUNET_malloc (needed);
   strcpy (ret, pfx);
   GNUNET_free (pfx);
-  va_start (ap, serviceName);
+  va_start (ap, service_name);
   while (1)
   {
     c = va_arg (ap, const char *);
@@ -1107,7 +1107,7 @@
  * Scan a directory for files.
  *
- * @param dirName the name of the directory
+ * @param dir_name the name of the directory
  * @param callback the method to call for each file,
  *        can be NULL, in that case, we only count
@@ -1310,7 +1310,7 @@
  *
  * @param prio priority to use
- * @param dirName the name of the directory
+ * @param dir_name the name of the directory
  * @param callback the method to call for each file
  * @param callback_cls closure for callback
@@ -1514,14 +1515,14 @@
  * Lock a part of a file
  * @param fh file handle
- * @param lockStart absolute position from where to lock
- * @param lockEnd absolute position until where to lock
+ * @param lock_start absolute position from where to lock
+ * @param lock_end absolute position until where to lock
  * @param excl GNUNET_YES for an exclusive lock
  * @return GNUNET_OK on success, GNUNET_SYSERR on error
@@ -1566,13 +1567,13 @@
  * Unlock a part of a file
  * @param fh file handle
- * @param unlockStart absolute position from where to unlock
- * @param unlockEnd absolute position until where to unlock
+ * @param unlock_start absolute position from where to unlock
+ * @param unlock_end absolute position until where to unlock
  * @return GNUNET_OK on success, GNUNET_SYSERR on error
  */
@@ -1925,7 +1927,7 @@
  *
  * @param cfg configuration to use (determines HOME)
- * @param serviceName name of the service
+ * @param service_name name of the service
  * @param ... is NULL-terminated list of
  *                path components to append to the




reply via email to

[Prev in Thread] Current Thread [Next in Thread]